"use client";

import Image from "next/image";
import { useState } from "react";

import { motion } from "framer-motion";

import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { ProductColor, ProductColorSelectorData } from "@/utils/get-fake-data";

interface ProductColorSelectorClientProps {
	data: ProductColorSelectorData;
	locale: Locale;
}

export function ProductColorSelectorClient({
	data,
	locale,
}: ProductColorSelectorClientProps) {
	const [selectedColor, setSelectedColor] = useState<ProductColor>("blue");
	const isRTL = locale === "ar";

	return (
		<section className="container mx-auto max-w-7xl px-4 py-16">
			<div className="text-center">
				<p
					className={cn(
						"mb-6 text-3xl text-custom-primary-accent sm:text-5xl",
						isRTL && "font-arabic"
					)}
				>
					{data.title?.[locale]}
				</p>
				<p
					className={cn(
						"mx-auto max-w-4xl text-lg text-[#757575]",
						isRTL && "font-arabic"
					)}
				>
					{data.description?.[locale]}
				</p>
			</div>

			<div className="mt-16">
				{/* Product Display */}
				<div className="relative mx-auto max-w-3xl">
					{/* Platform with animated border */}
					<div
						className="relative mx-auto aspect-[3/1] w-full"
						style={{
							background:
								"radial-gradient(ellipse at center, #fff 0%, #f8f9fa 100%)",
						}}
					>
						<div
							className="absolute inset-0"
							style={{
								background: `repeating-linear-gradient(90deg, ${data.colors.find((c) => c.id === selectedColor)?.value || "#2895C8"} 0, ${data.colors.find((c) => c.id === selectedColor)?.value || "#2895C8"} 10px, transparent 10px, transparent 20px)`,
								mask: "radial-gradient(ellipse at center, transparent 97%, black 100%)",
								WebkitMask:
									"radial-gradient(ellipse at center, transparent 97%, black 100%)",
							}}
						/>

						{/* Product Image */}
						<motion.div
							key={selectedColor}
							initial={{ opacity: 0, rotateY: -180 }}
							animate={{ opacity: 1, rotateY: 0 }}
							exit={{ opacity: 0, rotateY: 180 }}
							transition={{ duration: 0.6 }}
						//   className="absolute left-1/2 top-1/2 w-[80%] -translate-x-1/2 -translate-y-1/2"
						>
							<div className="relative aspect-[2/1]">
								<Image
									src={data.images[selectedColor]}
									alt={
										data.colors.find((c) => c.id === selectedColor)?.name[
										locale
										] || ""
									}
									fill
									className="object-contain"
									priority
								/>
							</div>
						</motion.div>
					</div>

					{/* Color Selection */}
					<div className="mt-8 flex justify-center gap-4">
						{data.colors?.map((color) => (
							<button
								key={color.id}
								onClick={() => setSelectedColor(color.id)}
								className={cn(
									"h-12 w-12 rounded-full transition-transform hover:scale-110",
									selectedColor === color.id && "ring-4 ring-offset-2"
								)}
								style={{
									backgroundColor: color.value,
								}}
								aria-label={color.name?.[locale]}
							/>
						))}
					</div>
				</div>
			</div>
		</section>
	);
}
